@@ -134,6 +134,7 @@ gtk_source_style_scheme_finalize (GObject *object)
 
 	if (scheme->priv->authors != NULL)
 	{
+		g_ptr_array_foreach (scheme->priv->authors, (GFunc)g_free, NULL);
 		g_ptr_array_free (scheme->priv->authors, TRUE);
 	}
 
@@ -957,7 +958,7 @@ generate_css_style (GtkSourceStyleScheme *scheme)
 	style = gtk_source_style_scheme_get_style (scheme, STYLE_CURRENT_LINE_NUMBER);
 	if (style != NULL)
 	{
-		append_css_style (final_style, style, "textview .current-line-number");
+		append_css_style (final_style, style, ".current-line-number");
 	}
 
 	if (*final_style->str != '\0')
@@ -1233,7 +1234,7 @@ parse_style_scheme_child (GtkSourceStyleScheme *scheme,
 	{
 		xmlChar *tmp = xmlNodeGetContent (node);
 		if (scheme->priv->authors == NULL)
-			scheme->priv->authors = g_ptr_array_new_with_free_func (g_free);
+			scheme->priv->authors = g_ptr_array_new ();
 
 		g_ptr_array_add (scheme->priv->authors, g_strdup ((char*) tmp));
 
@@ -1440,11 +1441,6 @@ _gtk_source_style_scheme_set_parent (GtkSourceStyleScheme *scheme,
 	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme));
 	g_return_if_fail (parent_scheme == NULL || GTK_SOURCE_IS_STYLE_SCHEME (parent_scheme));
 
-	if (scheme->priv->parent == parent_scheme)
-	{
-		return;
-	}
-
 	g_clear_object (&scheme->priv->parent);
 
 	if (parent_scheme != NULL)
@@ -1453,10 +1449,6 @@ _gtk_source_style_scheme_set_parent (GtkSourceStyleScheme *scheme,
 	}
 
 	scheme->priv->parent = parent_scheme;
-
-	/* Update CSS based on parent styles */
-	g_hash_table_remove_all (scheme->priv->style_cache);
-	generate_css_style (scheme);
 }
 
 /**
